<?php
/**
 * @file
 * Field validation numeric validator.
 *
 */
$plugin = array(
  'label' => t('(Deprecated)Numeric values'),
  'description' => t('(Deprecated)Verifies that user-entered values are numeric, with the option to specify min and / or max values.'),
  'handler' => array(
    'class' => 'field_validation_numeric_validator',
  ),
);

class field_validation_numeric_validator extends field_validation_validator {

  /**
   * Validate field. 
   */
  public function validate() {
    //$settings = $this->rule->settings;
    $settings = $this->numeric_check_data($this->rule->settings['data']);
    if ($this->value != '') {
      $flag = TRUE;
      if (!is_numeric($this->value)) {
        $flag = FALSE;
      }
      else{
        if (isset($settings['min']) && $settings['min'] != '' && $this->value < $settings['min']) {
          $flag = FALSE;
        }
        if (isset($settings['max']) && $settings['max'] != '' && $this->value > $settings['max']) {
          $flag = FALSE;
        }       
      }
      if (!$flag) {
        $this->set_error();
      }
    }
  }
  
  /**
   * Provide settings option
   */
  function settings_form(&$form, &$form_state) {
    $default_settings = $this->get_default_settings($form, $form_state);
    //print debug($default_settings);
    $form['settings']['data'] = array(
      '#title' => t('(Deprecated)Specify numeric validation range'),
      '#description' => t('(Deprecated)Optionally specify the minimum-maximum range to validate the user-entered numeric value against.') . ' ' . t('Usage') . ':'
        . theme('item_list', array('items' => array(t('empty: no value validation'), t('"100": greater than or equal to 100'), t('"|100": less than or equal to 100 (including negative numbers)'), t('"0|100": greater than or equal to 0 &amp; less than or equal to 100'), t('"10|100": greater than or equal to 10 &amp; less than or equal to 100'), t('"-100|-10": greater than or equal to -100 &amp; less than or equal to -10')))),
      '#type' => 'textfield',
      '#default_value' => isset($default_settings['data']) ? $default_settings['data'] : '',
    );
  }
  
  /**
   * Process the numeric value validation range that was provided in the numeric validator options
   */
  function numeric_check_data($data) {
    $range = array('min' => NULL, 'max' => NULL);
    // if no value was specified, don't validate
    if ($data == '') {
      return $range;
    }

    // If only one numeric value was specified, this is the min value
    if (is_numeric($data)) {
      $range['min'] = (int) $data;
    }

    if (strpos($data, '|') !== FALSE) {
      list($min, $max) = explode('|', $data);
      if ($min != '' && is_numeric($min)) {
        $range['min'] = (int) $min;
      }
      if ($max != '' && is_numeric($max)) {
        $range['max'] = (int) $max;
      }
    }
    return $range;
  }
}